@@ -18,9 +18,9 @@ from pycloudlib import (
     LXDVirtualMachine,
     Openstack,
 )
-from pycloudlib.cloud import BaseCloud
+from pycloudlib.cloud import BaseCloud, ImageType
 from pycloudlib.lxd.cloud import _BaseLXD
-from pycloudlib.lxd.instance import LXDInstance
+from pycloudlib.lxd.instance import BaseInstance, LXDInstance
 
 import cloudinit
 from cloudinit.subp import ProcessExecutionError, subp
@@ -94,7 +94,12 @@ class IntegrationCloud(ABC):
     datasource: str
     cloud_instance: BaseCloud
 
-    def __init__(self, settings=integration_settings):
+    def __init__(
+        self,
+        image_type: ImageType = ImageType.GENERIC,
+        settings=integration_settings,
+    ):
+        self._image_type = image_type
         self.settings = settings
         self.cloud_instance: BaseCloud = self._get_cloud_instance()
         self.initial_image_id = self._get_initial_image()
@@ -119,14 +124,15 @@ class IntegrationCloud(ABC):
     def _get_cloud_instance(self):
         raise NotImplementedError
 
-    def _get_initial_image(self):
+    def _get_initial_image(self, **kwargs) -> str:
         image = ImageSpecification.from_os_image()
         try:
-            return self.cloud_instance.daily_image(image.image_id)
-        except (ValueError, IndexError):
+            return self.cloud_instance.daily_image(image.image_id, **kwargs)
+        except (ValueError, IndexError) as ex:
+            log.debug("Exception while executing `daily_image`: %s", ex)
             return image.image_id
 
-    def _perform_launch(self, launch_kwargs, **kwargs):
+    def _perform_launch(self, launch_kwargs, **kwargs) -> BaseInstance:
         pycloudlib_instance = self.cloud_instance.launch(**launch_kwargs)
         return pycloudlib_instance
 
@@ -145,10 +151,11 @@ class IntegrationCloud(ABC):
                 "Instance id: %s",
                 self.settings.EXISTING_INSTANCE_ID,
             )
-            self.instance = self.cloud_instance.get_instance(
+            pycloudlib_instance = self.cloud_instance.get_instance(
                 self.settings.EXISTING_INSTANCE_ID
             )
-            return self.instance
+            instance = self.get_instance(pycloudlib_instance, settings)
+            return instance
         default_launch_kwargs = {
             "image_id": self.image_id,
             "user_data": user_data,
@@ -174,7 +181,9 @@ class IntegrationCloud(ABC):
                 log.info("image serial: %s", serial.split()[1])
         return instance
 
-    def get_instance(self, cloud_instance, settings=integration_settings):
+    def get_instance(
+        self, cloud_instance, settings=integration_settings
+    ) -> IntegrationInstance:
         return IntegrationInstance(self, cloud_instance, settings)
 
     def destroy(self):
@@ -205,6 +214,11 @@ class Ec2Cloud(IntegrationCloud):
     def _get_cloud_instance(self):
         return EC2(tag="ec2-integration-test")
 
+    def _get_initial_image(self, **kwargs) -> str:
+        return super()._get_initial_image(
+            image_type=self._image_type, **kwargs
+        )
+
     def _perform_launch(self, launch_kwargs, **kwargs):
         """Use a dual-stack VPC for cloud-init integration testing."""
         if "vpc" not in launch_kwargs:
@@ -231,6 +245,11 @@ class GceCloud(IntegrationCloud):
             tag="gce-integration-test",
         )
 
+    def _get_initial_image(self, **kwargs) -> str:
+        return super()._get_initial_image(
+            image_type=self._image_type, **kwargs
+        )
+
 
 class AzureCloud(IntegrationCloud):
     datasource = "azure"
@@ -239,6 +258,11 @@ class AzureCloud(IntegrationCloud):
     def _get_cloud_instance(self):
         return Azure(tag="azure-integration-test")
 
+    def _get_initial_image(self, **kwargs) -> str:
+        return super()._get_initial_image(
+            image_type=self._image_type, **kwargs
+        )
+
     def destroy(self):
         if self.settings.KEEP_INSTANCE:
             log.info(
@@ -363,7 +387,7 @@ class OpenstackCloud(IntegrationCloud):
             tag="openstack-integration-test",
         )
 
-    def _get_initial_image(self):
+    def _get_initial_image(self, **kwargs):
         image = ImageSpecification.from_os_image()
         try:
             UUID(image.image_id)
