@@ -211,7 +211,7 @@ SECONDARY_IP_METADATA_2018_09_24 = {
 
 M_PATH_NET = "cloudinit.sources.DataSourceEc2.net."
 
-TAGS_METADATA_2021_03_23 = {
+TAGS_METADATA_2021_03_23: dict = {
     **DEFAULT_METADATA,
     "tags": {
         "instance": {
@@ -548,7 +548,7 @@ class TestEc2(test_helpers.HttprettyTestCase):
                 ):
                     del responses.mock._urls[index]
         elif hasattr(responses.mock, "_matches"):
-            # Can be removed when Focal and Impish are EOL
+            # Can be removed when Focal is EOL
             for index, response in enumerate(responses.mock._matches):
                 if response.url.startswith(
                     "http://169.254.169.254/2009-04-04/meta-data/"
@@ -837,13 +837,14 @@ class TestEc2(test_helpers.HttprettyTestCase):
             self.logs.getvalue(),
         )
 
-    @mock.patch("cloudinit.net.dhcp.EphemeralIPv4Network")
+    @mock.patch("cloudinit.net.ephemeral.EphemeralIPv6Network")
+    @mock.patch("cloudinit.net.ephemeral.EphemeralIPv4Network")
     @mock.patch("cloudinit.net.find_fallback_nic")
-    @mock.patch("cloudinit.net.dhcp.maybe_perform_dhcp_discovery")
+    @mock.patch("cloudinit.net.ephemeral.maybe_perform_dhcp_discovery")
     @mock.patch("cloudinit.sources.DataSourceEc2.util.is_FreeBSD")
     @responses.activate
     def test_ec2_local_performs_dhcp_on_non_bsd(
-        self, m_is_bsd, m_dhcp, m_fallback_nic, m_net
+        self, m_is_bsd, m_dhcp, m_fallback_nic, m_net4, m_net6
     ):
         """Ec2Local returns True for valid platform data on non-BSD with dhcp.
 
@@ -873,7 +874,7 @@ class TestEc2(test_helpers.HttprettyTestCase):
         ret = ds.get_data()
         self.assertTrue(ret)
         m_dhcp.assert_called_once_with("eth9", None)
-        m_net.assert_called_once_with(
+        m_net4.assert_called_once_with(
             broadcast="192.168.2.255",
             interface="eth9",
             ip="192.168.2.9",
@@ -881,7 +882,7 @@ class TestEc2(test_helpers.HttprettyTestCase):
             router="192.168.2.1",
             static_routes=None,
         )
-        self.assertIn("Crawl of metadata service took", self.logs.getvalue())
+        self.assertIn("Crawl of metadata service ", self.logs.getvalue())
 
     @responses.activate
     def test_get_instance_tags(self):
