@@ -15,6 +15,7 @@ from cloudinit.url_helper import (
     NOT_FOUND,
     REDACTED,
     UrlError,
+    UrlResponse,
     dual_stack,
     oauth_headers,
     read_file_or_url,
@@ -92,6 +93,18 @@ class TestReadFileOrUrl(CiTestCase):
         self.assertEqual(result.contents, data)
         self.assertEqual(str(result), data.decode("utf-8"))
 
+    @httpretty.activate
+    def test_read_file_or_url_str_from_url_streamed(self):
+        """Test that str(result.contents) on url is text version of contents.
+        It should not be "b'data'", but just "'data'" """
+        url = "http://hostname/path"
+        data = b"This is my url content\n"
+        httpretty.register_uri(httpretty.GET, url, data)
+        result = read_file_or_url(url, stream=True)
+        assert isinstance(result, UrlResponse)
+        self.assertEqual(result.contents, data)
+        self.assertEqual(str(result), data.decode("utf-8"))
+
     @httpretty.activate
     def test_read_file_or_url_str_from_url_redacting_headers_from_logs(self):
         """Headers are redacted from logs but unredacted in requests."""
@@ -146,6 +159,7 @@ class TestReadFileOrUrl(CiTestCase):
                             "User-Agent": "Cloud-Init/%s"
                             % (version.version_string())
                         },
+                        "stream": False,
                     },
                     kwargs,
                 )
@@ -186,6 +200,7 @@ class TestReadFileOrUrlParameters:
             "ssl_details": {"cert_file": "/path/cert.pem"},
             "headers_cb": "headers_cb",
             "exception_cb": "exception_cb",
+            "stream": True,
         }
 
         assert response == read_file_or_url(**params)
@@ -222,6 +237,7 @@ class TestReadFileOrUrlParameters:
                         % (version.version_string())
                     },
                     "timeout": request_timeout,
+                    "stream": False,
                 }
                 if request_timeout is None:
                     expected_kwargs.pop("timeout")
@@ -282,7 +298,7 @@ class TestDualStack:
     """
 
     @pytest.mark.parametrize(
-        "func," "addresses," "stagger_delay," "timeout," "expected_val,",
+        ["func", "addresses", "stagger_delay", "timeout", "expected_val"],
         [
             # Assert order based on timeout
             (lambda x, _: x, ("one", "two"), 1, 1, "one"),
@@ -346,12 +362,14 @@ class TestDualStack:
         event.set()
 
     @pytest.mark.parametrize(
-        "func,"
-        "addresses,"
-        "stagger_delay,"
-        "timeout,"
-        "message,"
-        "expected_exc",
+        [
+            "func",
+            "addresses",
+            "stagger_delay",
+            "timeout",
+            "message",
+            "expected_exc",
+        ],
         [
             (
                 lambda _a, _b: 1 / 0,
@@ -370,7 +388,7 @@ class TestDualStack:
                 ZeroDivisionError,
             ),
             (
-                lambda _a, _b: [][0],
+                lambda _a, _b: [][0],  # pylint: disable=E0643
                 ("matter", "these"),
                 0,
                 1,
@@ -479,7 +497,7 @@ class TestUrlHelper:
         return (200, {"request-id": "0"}, cls.success)
 
     @pytest.mark.parametrize(
-        "addresses," "expected_address_index," "response,",
+        ["addresses", "expected_address_index", "response"],
         [
             # Use timeout to test ordering happens as expected
             ((ADDR1, SLEEP1), 0, "SUCCESS"),
